@@ -2,7 +2,7 @@
 || This file is part of Pike. For copyright information see COPYRIGHT.
 || Pike is distributed under GPL, LGPL and MPL. See the file COPYING
 || for more information.
-|| $Id: acconfig.h,v 1.141 2004/04/14 11:42:22 grubba Exp $
+|| $Id: acconfig.h,v 1.144 2006/08/06 16:58:07 mast Exp $
 */
 
 #ifndef MACHINE_H
@@ -38,6 +38,9 @@
 /* Define this if you are going to use a memory access checker (like Purify) */
 #undef __CHECKER__
 
+/* Defined if Doug Leas malloc implementation is used. */
+#undef USE_DL_MALLOC
+
 /* Define this if you want malloc debugging */
 #undef DEBUG_MALLOC
 
@@ -74,6 +77,10 @@
 /* Enable internal profiling */
 #undef INTERNAL_PROFILING
 
+/* If possible, the expansion for a "#define short" to avoid that bison
+ * uses short everywhere internally. */
+#undef BISON_SHORT_EXPANSION
+
 /* The following USE_* are used by smartlink */
 /* Define this if your ld sets the run path with -rpath */
 #undef USE_RPATH
@@ -277,6 +284,9 @@
 /* Define if you have a working, 8-bit-clean memcmp */
 #undef HAVE_MEMCMP
 
+/* Define if it is possible to allocate PROT_EXEC memory with mmap */
+#undef MEXEC_USES_MMAP
+
 /* Define if you have gethostname */
 #undef HAVE_GETHOSTNAME
 
