@@ -2,7 +2,7 @@
 || This file is part of Pike. For copyright information see COPYRIGHT.
 || Pike is distributed under GPL, LGPL and MPL. See the file COPYING
 || for more information.
-|| $Id: cpp.c,v 1.139 2004/09/21 17:55:35 nilsson Exp $
+|| $Id: cpp.c,v 1.141 2004/11/01 03:05:23 mast Exp $
 */
 
 #include "global.h"
@@ -916,11 +916,13 @@ while(1)					\
     if(data[pos+1]=='\n')			\
     {						\
       pos++;					\
+      this->current_line++;			\
       continue;					\
     }						\
     if(data[pos+1]=='\r' && data[pos+2]=='\n')	\
     {						\
       pos+=2;					\
+      this->current_line++;			\
       continue;					\
     }						\
     READCHAR(tmp);				\
@@ -1034,7 +1036,7 @@ while(1)					\
 
 #define FINDTOK() 				\
   do {						\
-  SKIPSPACE();					\
+  SKIPWHITE();					\
   if(data[pos]=='/')				\
   {						\
     ptrdiff_t tmp;				\
