@@ -2,11 +2,11 @@
 || This file is part of Pike. For copyright information see COPYRIGHT.
 || Pike is distributed under GPL, LGPL and MPL. See the file COPYING
 || for more information.
-|| $Id: interpret.c,v 1.352 2004/08/19 15:00:37 grubba Exp $
+|| $Id: interpret.c,v 1.354 2007/04/15 12:18:21 peter Exp $
 */
 
 #include "global.h"
-RCSID("$Id: interpret.c,v 1.352 2004/08/19 15:00:37 grubba Exp $");
+RCSID("$Id: interpret.c,v 1.354 2007/04/15 12:18:21 peter Exp $");
 #include "interpret.h"
 #include "object.h"
 #include "program.h"
@@ -167,7 +167,8 @@ void gc_mark_stack_external (struct pike_frame *f,
 
 static void gc_check_stack_callback(struct callback *foo, void *bar, void *gazonk)
 {
-  gc_mark_stack_external (Pike_fp, Pike_sp, Pike_interpreter.evaluator_stack);
+  if (Pike_interpreter.evaluator_stack)
+    gc_mark_stack_external (Pike_fp, Pike_sp, Pike_interpreter.evaluator_stack);
 }
 #endif
 
@@ -1421,7 +1422,7 @@ static void do_trace_call(INT32 args, dynamic_buffer *old_buf)
       file = "...";
     else {
       file = filep->str;
-      while((f=STRCHR(file,'/')))
+      while((f=STRCHR(file,'/')) || (f=STRCHR(file,'\\')))
 	file=f+1;
     }
   }else{
@@ -1430,7 +1431,7 @@ static void do_trace_call(INT32 args, dynamic_buffer *old_buf)
   }
 
   {
-    char buf[40];
+    char buf[100];
     if (linep)
       SNPRINTF(buf, sizeof (buf), "%s:%ld:", file, (long)linep);
     else
