@@ -2,13 +2,14 @@
 || This file is part of Pike. For copyright information see COPYRIGHT.
 || Pike is distributed under GPL, LGPL and MPL. See the file COPYING
 || for more information.
-|| $Id: mapping.h,v 1.54 2004/04/18 02:16:06 mast Exp $
+|| $Id: mapping.h,v 1.57 2004/09/28 23:58:35 mast Exp $
 */
 
 #ifndef MAPPING_H
 #define MAPPING_H
 
 #include "svalue.h"
+#include "dmalloc.h"
 #include "block_alloc_h.h"
 
 /* Compatible with PIKE_WEAK_INDICES and PIKE_WEAK_VALUES. */
@@ -85,10 +86,10 @@ extern struct mapping *gc_internal_mapping;
 #define free_mapping(M) do{						\
     struct mapping *m_=(M);						\
     debug_malloc_touch(m_);						\
-    DO_IF_PIKE_CLEANUP (						\
-      if (gc_external_refs_zapped)					\
-	gc_check_zapped (m_, PIKE_T_MAPPING, __FILE__, __LINE__);	\
-    );									\
+    DO_IF_DEBUG (							\
+      DO_IF_PIKE_CLEANUP (						\
+	if (gc_external_refs_zapped)					\
+	  gc_check_zapped (m_, PIKE_T_MAPPING, __FILE__, __LINE__)));	\
     if(!sub_ref(m_))							\
       really_free_mapping(m_);						\
   }while(0)
