@@ -2,11 +2,11 @@
 || This file is part of Pike. For copyright information see COPYRIGHT.
 || Pike is distributed under GPL, LGPL and MPL. See the file COPYING
 || for more information.
-|| $Id: png.c,v 1.63 2004/04/20 08:19:03 grubba Exp $
+|| $Id: png.c,v 1.66 2006/08/14 13:09:25 nilsson Exp $
 */
 
 #include "global.h"
-RCSID("$Id: png.c,v 1.63 2004/04/20 08:19:03 grubba Exp $");
+RCSID("$Id: png.c,v 1.66 2006/08/14 13:09:25 nilsson Exp $");
 
 #include "image_machine.h"
 
@@ -729,28 +729,25 @@ static int _png_write_rgb(rgb_group *w1,
 		  while (n)
 		  {
 		     int i;
-		     for (i=8; i;)
+		     for (i=8; i; i--)
 		     {
-			i--;
-			if (x) 
-			{
-			   int m=((*s)>>i)&1;
-			   x--;
-			   *(d1++)=ct->u.flat.entries[CUTPLTE(m,mz)].color;
-			   if (m>=trns->len)
-			      *(da1++)=white;
-			   else
-			   {
-			      da1->r=trns->str[m];
-			      da1->g=trns->str[m];
-			      da1->b=trns->str[m];
-			      da1++;
-			   }
-			}
+                       int m=((*s)>>(i-1))&1;
+                       if (!x) break;
+                       x--;
+                       *(d1++)=ct->u.flat.entries[CUTPLTE(m,mz)].color;
+                       if (m>=trns->len)
+                         *(da1++)=white;
+                       else
+                       {
+                         da1->r=trns->str[m];
+                         da1->g=trns->str[m];
+                         da1->b=trns->str[m];
+                         da1++;
+                       }
 		     }
 		     s++;
-		     if (n<8) break;
-		     n-=8;
+		     if (n<8 && n<width) break;
+		     n -= (8-i);
 		     if (!x) x=width;
 		  }
 	       break;
@@ -1320,7 +1317,7 @@ static void img_png_decode(INT32 args,int header_only)
 	    free(w1); 
 	    if (wa1) free(wa1); 
 	    if (ta1) free(ta1); 
-	    if (ta1) free(t1); 
+	    if (t1) free(t1);
 	    Pike_error("Image.PNG._decode: out of memory (close one)\n");
 	 }
 	 /* loop over adam7 interlace's 
@@ -1580,25 +1577,27 @@ static void image_png_encode(INT32 args)
       }
       else
       {
-	 unsigned char *tmp=malloc(img->xsize*img->ysize),*ts;
+         unsigned char *d;
+         struct pike_string *ps;
+	 unsigned char *tmp, *ts;
 
-	 if (!tmp)
-	    PIKE_ERROR("Image.PNG.encode", "Out of memory.\n", sp, args);
-	 image_colortable_index_8bit_image(ct,img->img,tmp,
-					   img->xsize*img->ysize,img->xsize);
+         x = img->xsize;
+         tmp=xalloc(x*y);
+
+	 image_colortable_index_8bit_image(ct,s,tmp,x*y,x);
+         ps=begin_shared_string( y * ((x*bpp+7)/8+1) );
+         d=(unsigned char*)ps->str;
 	 ts=tmp;
+
 	 while (y--)
 	 {
-	    unsigned char *d;
-	    struct pike_string *ps;
-	    ps=begin_shared_string((img->xsize*bpp+7)/8+1);
-	    d=(unsigned char*)ps->str;
 	    x=img->xsize;
 	    *(d++)=0; /* filter */
 	    if (bpp==8)
 	    {
-	       MEMCPY(d,ts,img->xsize);
-	       ts+=img->xsize;
+	       MEMCPY(d,ts,x);
+	       ts += x;
+               d += x;
 	    }
 	    else
 	    {
@@ -1612,12 +1611,14 @@ static void image_png_encode(INT32 args)
 		  ts++;
 	       }
 	    }
-	    push_string(end_shared_string(ps));
 	 }
+
+         push_string(end_shared_string(ps));
 	 free(tmp);
       }
    }
    else
+   {
       while (y--)
       {
 	 struct pike_string *ps;
@@ -1646,7 +1647,9 @@ static void image_png_encode(INT32 args)
 	    }
 	 push_string(end_shared_string(ps));
       }
-   f_add(img->ysize);
+      f_add(img->ysize);
+   }
+
    png_compress(0);
    push_png_chunk("IDAT",NULL);
    n++;
