@@ -2,12 +2,12 @@
 || This file is part of Pike. For copyright information see COPYRIGHT.
 || Pike is distributed under GPL, LGPL and MPL. See the file COPYING
 || for more information.
-|| $Id: file.c,v 1.319 2004/08/26 21:26:26 vida Exp $
+|| $Id: file.c,v 1.323 2006/03/05 22:22:20 marcus Exp $
 */
 
 #define NO_PIKE_SHORTHAND
 #include "global.h"
-RCSID("$Id: file.c,v 1.319 2004/08/26 21:26:26 vida Exp $");
+RCSID("$Id: file.c,v 1.323 2006/03/05 22:22:20 marcus Exp $");
 #include "fdlib.h"
 #include "pike_netlib.h"
 #include "interpret.h"
@@ -188,7 +188,7 @@ static void debug_check_internals (struct my_file *f)
   for (ev = 0; ev < NELEM (f->event_cbs); ev++)
     if (f->event_cbs[ev].type == PIKE_T_INT &&
 	f->box.backend && f->box.events & (1 << ev))
-      Pike_fatal ("Got event flag but no callback for event %d.\n", ev);
+      Pike_fatal ("Got event flag but no callback for event %"PRINTSIZET"d.\n", ev);
 }
 #else
 #define debug_check_internals(f) do {} while (0)
@@ -986,8 +986,10 @@ static void file__enable_callbacks(INT32 args)
   size_t ev;
   int cb_events = 0;
 
+#if 0
   if(FD<0)
     Pike_error("File is not open.\n");
+#endif
 
   debug_check_internals (f);
 
@@ -1005,8 +1007,10 @@ static void file__disable_callbacks(INT32 args)
 {
   struct my_file *f = THIS;
 
+#if 0
   if(FD<0)
     Pike_error("File is not open.\n");
+#endif
 
   SUB_FD_EVENTS (f, ~0);
 
@@ -3101,7 +3105,7 @@ static void file_connect(INT32 args)
   struct svalue *dest_port = NULL;
   struct svalue *src_port = NULL;
 
-  int tmp;
+  int tmp, was_closed = FD < 0;
 
   if (args < 4) {
     get_all_args("Stdio.File->connect", args, "%S%*", &dest_addr, &dest_port);
@@ -3124,7 +3128,7 @@ static void file_connect(INT32 args)
 			   (dest_port->type == PIKE_T_INT?
 			    dest_port->u.integer : -1), 0);
 
-  if(FD < 0)
+  if(was_closed)
   {
     if (args < 4) {
       push_int(-1);
@@ -3160,6 +3164,11 @@ static void file_connect(INT32 args)
   {
     /* something went wrong */
     ERRNO=errno;
+    if (was_closed) {
+      while (fd_close (FD) && errno == EINTR) {}
+      change_fd_for_box (&THIS->box, -1);
+      errno = ERRNO;
+    }
     pop_n_elems(args);
     push_int(0);
   }else{
@@ -3295,17 +3304,17 @@ static void file_create(INT32 args)
 struct new_thread_data
 {
   INT32 from, to;
+  char buffer[READ_BUFFER];
 };
 
 static TH_RETURN_TYPE proxy_thread(void * data)
 {
-  char buffer[READ_BUFFER];
   struct new_thread_data *p=(struct new_thread_data *)data;
 
   while(1)
   {
     ptrdiff_t len, w;
-    len = fd_read(p->from, buffer, READ_BUFFER);
+    len = fd_read(p->from, p->buffer, READ_BUFFER);
     if(len==0) break;
     if(len<0)
     {
@@ -3317,7 +3326,7 @@ static TH_RETURN_TYPE proxy_thread(void * data)
     w=0;
     while(w<len)
     {
-      ptrdiff_t wl = fd_write(p->to, buffer+w, len-w);
+      ptrdiff_t wl = fd_write(p->to, p->buffer+w, len-w);
       if(wl<0)
       {
 	if(errno==EINTR) continue;
