@@ -1,4 +1,4 @@
-#line 1 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/hash.cmod"
+#line 1 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
 /* hash.cmod -*- c -*- */
 
 #include "global.h"
@@ -53,8 +53,8 @@ werror(const char *format, ...)
 
 #undef class_HashInfo_defined
 #define class_HashInfo_defined
-struct program *HashInfo_program=0;
-int HashInfo_program_fun_num=-1;
+struct program *HashInfo_program=NULL;
+static int HashInfo_program_fun_num=-1;
 
 #undef var_meta_HashInfo_defined
 #define var_meta_HashInfo_defined
@@ -74,7 +74,7 @@ static ptrdiff_t HashInfo_storage_offset;
 struct HashInfo_struct {
 
 #ifdef var_meta_HashInfo_defined
-#line 54 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/hash.cmod"
+#line 54 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
 const struct nettle_hash *meta;
 #endif /* var_meta_HashInfo_defined */
 };
@@ -85,9 +85,9 @@ const struct nettle_hash *meta;
   #define f_HashInfo_name_defined
 ptrdiff_t f_HashInfo_name_fun_num = 0;
 void f_HashInfo_name(INT32 args) {
-#line 60 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/hash.cmod"
+#line 60 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
 if(args != 0) wrong_number_of_args_error("name",args,0);
-#line 62 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/hash.cmod"
+#line 62 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
 {
       if (!THIS->meta)
 	Pike_error("HashInfo not properly initialized.\n");
@@ -103,9 +103,9 @@ if(args != 0) wrong_number_of_args_error("name",args,0);
   #define f_HashInfo_digest_size_defined
 ptrdiff_t f_HashInfo_digest_size_fun_num = 0;
 void f_HashInfo_digest_size(INT32 args) {
-#line 73 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/hash.cmod"
+#line 73 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
 if(args != 0) wrong_number_of_args_error("digest_size",args,0);
-#line 75 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/hash.cmod"
+#line 75 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
 {
       if (!THIS->meta)
 	Pike_error("HashInfo not properly initialized.\n");
@@ -121,9 +121,9 @@ if(args != 0) wrong_number_of_args_error("digest_size",args,0);
   #define f_HashInfo_block_size_defined
 ptrdiff_t f_HashInfo_block_size_fun_num = 0;
 void f_HashInfo_block_size(INT32 args) {
-#line 86 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/hash.cmod"
+#line 86 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
 if(args != 0) wrong_number_of_args_error("block_size",args,0);
-#line 88 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/hash.cmod"
+#line 88 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
 {
       if (!THIS->meta)
 	Pike_error("HashInfo not properly initialized.\n");
@@ -138,7 +138,7 @@ if(args != 0) wrong_number_of_args_error("block_size",args,0);
 #undef HashInfo_event_handler_defined
 #define HashInfo_event_handler_defined
 static void init_HashInfo_struct(void)
-#line 95 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/hash.cmod"
+#line 95 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
 {
       werror("HashInfo->INIT\n");
       THIS->meta = NULL;
@@ -159,7 +159,7 @@ static void HashInfo_event_handler(int ev) {
 #endif /* HashInfo_event_handler_defined */
 /*! @endclass HashInfo */
 
-#line 103 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/hash.cmod"
+#line 103 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
 #define GET_META(o) \
 ( ((struct HashInfo_struct *) get_storage((o), HashInfo_program)) \
   ->meta)
@@ -173,8 +173,8 @@ static void HashInfo_event_handler(int ev) {
 
 #undef class_HashState_defined
 #define class_HashState_defined
-struct program *HashState_program=0;
-int HashState_program_fun_num=-1;
+struct program *HashState_program=NULL;
+static int HashState_program_fun_num=-1;
 
 #undef inherit_HashInfo_HashState_defined
 #define inherit_HashInfo_HashState_defined
@@ -197,11 +197,11 @@ static ptrdiff_t HashState_storage_offset;
 struct HashState_struct {
 
 #ifdef var_ctx_HashState_defined
-#line 116 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/hash.cmod"
+#line 116 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
 void *ctx;
 #endif /* var_ctx_HashState_defined */
 };
-#line 118 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/hash.cmod"
+#line 118 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
 /* FIXME: Create should copy state from the other object, if
    * provided. */
 
@@ -212,15 +212,15 @@ void *ctx;
   #define f_HashState_update_defined
 ptrdiff_t f_HashState_update_fun_num = 0;
 void f_HashState_update(INT32 args) {
-#line 125 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/hash.cmod"
+#line 125 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
 struct pike_string * data;
-#line 125 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/hash.cmod"
+#line 125 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
 if(args != 1) wrong_number_of_args_error("update",args,1);
-#line 125 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/hash.cmod"
+#line 125 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
 if(Pike_sp[0-1].type != PIKE_T_STRING) SIMPLE_BAD_ARG_ERROR("update",1,"string");
-#line 125 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/hash.cmod"
+#line 125 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
 debug_malloc_pass(data=Pike_sp[0-1].u.string);
-#line 127 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/hash.cmod"
+#line 127 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
 {
       const void *ctx = THIS->ctx;
       const struct nettle_hash *meta =
@@ -252,15 +252,17 @@ debug_malloc_pass(data=Pike_sp[0-1].u.string);
   #define f_HashState_digest_defined
 ptrdiff_t f_HashState_digest_fun_num = 0;
 void f_HashState_digest(INT32 args) {
-#line 154 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/hash.cmod"
+#line 154 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
 struct svalue * arg;
-#line 154 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/hash.cmod"
+#line 154 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
 if(args > 1) wrong_number_of_args_error("digest",args,1);
 if (args > 0) {
-#line 154 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/hash.cmod"
+#line 154 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
+if(Pike_sp[0-args].type != PIKE_T_INT) SIMPLE_BAD_ARG_ERROR("digest",1,"int|void");
+#line 154 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
 arg=Pike_sp+0-args; dmalloc_touch_svalue(Pike_sp+0-args);
 } else arg=0;
-#line 155 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/hash.cmod"
+#line 155 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
 {
       const struct nettle_hash *meta;
       struct pike_string *digest;
@@ -299,7 +301,7 @@ arg=Pike_sp+0-args; dmalloc_touch_svalue(Pike_sp+0-args);
 #undef HashState_event_handler_defined
 #define HashState_event_handler_defined
 static void init_HashState_struct(void)
-#line 186 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/hash.cmod"
+#line 186 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
 {
       werror("HashState->INIT\n");
       THIS->ctx = NULL;
@@ -311,7 +313,7 @@ static void init_HashState_struct(void)
 #undef HashState_event_handler_defined
 #define HashState_event_handler_defined
 static void exit_HashState_struct(void)
-#line 191 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/hash.cmod"
+#line 191 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
 {
       werror("HashState->EXIT\n");
       if (THIS->ctx && Pike_fp->current_object->prog)
@@ -351,8 +353,8 @@ static void HashState_event_handler(int ev) {
 
 #undef class_MD5_Info_defined
 #define class_MD5_Info_defined
-struct program *MD5_Info_program=0;
-int MD5_Info_program_fun_num=-1;
+struct program *MD5_Info_program=NULL;
+static int MD5_Info_program_fun_num=-1;
 
 #undef internal_init_MD5_Info_defined
 #define internal_init_MD5_Info_defined
@@ -360,7 +362,7 @@ int MD5_Info_program_fun_num=-1;
 #undef MD5_Info_event_handler_defined
 #define MD5_Info_event_handler_defined
 static void init_MD5_Info_struct(void)
-#line 213 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/hash.cmod"
+#line 213 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
 {
       struct HashInfo_struct *HashInfo
 	= (struct HashInfo_struct *) get_storage(Pike_fp->current_object,
@@ -399,8 +401,8 @@ static void MD5_Info_event_handler(int ev) {
 
 #undef class_MD5_State_defined
 #define class_MD5_State_defined
-struct program *MD5_State_program=0;
-int MD5_State_program_fun_num=-1;
+struct program *MD5_State_program=NULL;
+static int MD5_State_program_fun_num=-1;
 
 #undef inherit_MD5_Info_MD5_State_defined
 #define inherit_MD5_Info_MD5_State_defined
@@ -426,7 +428,7 @@ static ptrdiff_t MD5_State_storage_offset;
 struct MD5_State_struct {
 
 #ifdef var_md5_MD5_State_defined
-#line 240 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/hash.cmod"
+#line 240 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
 struct md5_ctx md5;
 #endif /* var_md5_MD5_State_defined */
 };
@@ -437,7 +439,7 @@ struct md5_ctx md5;
 #undef MD5_State_event_handler_defined
 #define MD5_State_event_handler_defined
 static void init_MD5_State_struct(void)
-#line 243 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/hash.cmod"
+#line 243 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
 {
       struct HashState_struct *instance
 	= (struct HashState_struct *) get_storage(Pike_fp->current_object,
@@ -465,7 +467,7 @@ static void MD5_State_event_handler(int ev) {
 #endif /* MD5_State_event_handler_defined */
 /*! @endclass MD5_State */
 
-#line 257 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/hash.cmod"
+#line 257 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
 #ifdef HAVE_NETTLE_MD4_INIT
 
 /*! @class MD4_Info
@@ -476,8 +478,8 @@ static void MD5_State_event_handler(int ev) {
 
 #undef class_MD4_Info_defined
 #define class_MD4_Info_defined
-struct program *MD4_Info_program=0;
-int MD4_Info_program_fun_num=-1;
+struct program *MD4_Info_program=NULL;
+static int MD4_Info_program_fun_num=-1;
 
 #undef internal_init_MD4_Info_defined
 #define internal_init_MD4_Info_defined
@@ -485,7 +487,7 @@ int MD4_Info_program_fun_num=-1;
 #undef MD4_Info_event_handler_defined
 #define MD4_Info_event_handler_defined
 static void init_MD4_Info_struct(void)
-#line 267 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/hash.cmod"
+#line 267 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
 {
       struct HashInfo_struct *HashInfo
 	= (struct HashInfo_struct *) get_storage(Pike_fp->current_object,
@@ -524,8 +526,8 @@ static void MD4_Info_event_handler(int ev) {
 
 #undef class_MD4_State_defined
 #define class_MD4_State_defined
-struct program *MD4_State_program=0;
-int MD4_State_program_fun_num=-1;
+struct program *MD4_State_program=NULL;
+static int MD4_State_program_fun_num=-1;
 
 #undef inherit_MD4_Info_MD4_State_defined
 #define inherit_MD4_Info_MD4_State_defined
@@ -551,7 +553,7 @@ static ptrdiff_t MD4_State_storage_offset;
 struct MD4_State_struct {
 
 #ifdef var_md4_MD4_State_defined
-#line 294 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/hash.cmod"
+#line 294 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
 struct md4_ctx md4;
 #endif /* var_md4_MD4_State_defined */
 };
@@ -562,7 +564,7 @@ struct md4_ctx md4;
 #undef MD4_State_event_handler_defined
 #define MD4_State_event_handler_defined
 static void init_MD4_State_struct(void)
-#line 297 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/hash.cmod"
+#line 297 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
 {
       struct HashState_struct *instance
 	= (struct HashState_struct *) get_storage(Pike_fp->current_object,
@@ -598,8 +600,8 @@ static void MD4_State_event_handler(int ev) {
 
 #undef class_MD2_Info_defined
 #define class_MD2_Info_defined
-struct program *MD2_Info_program=0;
-int MD2_Info_program_fun_num=-1;
+struct program *MD2_Info_program=NULL;
+static int MD2_Info_program_fun_num=-1;
 
 #undef internal_init_MD2_Info_defined
 #define internal_init_MD2_Info_defined
@@ -607,7 +609,7 @@ int MD2_Info_program_fun_num=-1;
 #undef MD2_Info_event_handler_defined
 #define MD2_Info_event_handler_defined
 static void init_MD2_Info_struct(void)
-#line 319 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/hash.cmod"
+#line 319 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
 {
       struct HashInfo_struct *HashInfo
 	= (struct HashInfo_struct *) get_storage(Pike_fp->current_object,
@@ -646,8 +648,8 @@ static void MD2_Info_event_handler(int ev) {
 
 #undef class_MD2_State_defined
 #define class_MD2_State_defined
-struct program *MD2_State_program=0;
-int MD2_State_program_fun_num=-1;
+struct program *MD2_State_program=NULL;
+static int MD2_State_program_fun_num=-1;
 
 #undef inherit_MD2_Info_MD2_State_defined
 #define inherit_MD2_Info_MD2_State_defined
@@ -673,7 +675,7 @@ static ptrdiff_t MD2_State_storage_offset;
 struct MD2_State_struct {
 
 #ifdef var_md2_MD2_State_defined
-#line 346 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/hash.cmod"
+#line 346 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
 struct md2_ctx md2;
 #endif /* var_md2_MD2_State_defined */
 };
@@ -684,7 +686,7 @@ struct md2_ctx md2;
 #undef MD2_State_event_handler_defined
 #define MD2_State_event_handler_defined
 static void init_MD2_State_struct(void)
-#line 349 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/hash.cmod"
+#line 349 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
 {
       struct HashState_struct *instance
 	= (struct HashState_struct *) get_storage(Pike_fp->current_object,
@@ -712,7 +714,7 @@ static void MD2_State_event_handler(int ev) {
 #endif /* MD2_State_event_handler_defined */
 /*! @endclass MD2_State */
 
-#line 363 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/hash.cmod"
+#line 363 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
 #endif /* HAVE_NETTLE_MD4_INIT */
 
 /*! @class SHA1_Info
@@ -723,8 +725,8 @@ static void MD2_State_event_handler(int ev) {
 
 #undef class_SHA1_Info_defined
 #define class_SHA1_Info_defined
-struct program *SHA1_Info_program=0;
-int SHA1_Info_program_fun_num=-1;
+struct program *SHA1_Info_program=NULL;
+static int SHA1_Info_program_fun_num=-1;
 
 #undef internal_init_SHA1_Info_defined
 #define internal_init_SHA1_Info_defined
@@ -732,7 +734,7 @@ int SHA1_Info_program_fun_num=-1;
 #undef SHA1_Info_event_handler_defined
 #define SHA1_Info_event_handler_defined
 static void init_SHA1_Info_struct(void)
-#line 373 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/hash.cmod"
+#line 373 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
 {
       struct HashInfo_struct *HashInfo
 	= (struct HashInfo_struct *) get_storage(Pike_fp->current_object,
@@ -772,8 +774,8 @@ static void SHA1_Info_event_handler(int ev) {
 
 #undef class_SHA1_State_defined
 #define class_SHA1_State_defined
-struct program *SHA1_State_program=0;
-int SHA1_State_program_fun_num=-1;
+struct program *SHA1_State_program=NULL;
+static int SHA1_State_program_fun_num=-1;
 
 #undef inherit_SHA1_Info_SHA1_State_defined
 #define inherit_SHA1_Info_SHA1_State_defined
@@ -799,7 +801,7 @@ static ptrdiff_t SHA1_State_storage_offset;
 struct SHA1_State_struct {
 
 #ifdef var_sha1_SHA1_State_defined
-#line 401 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/hash.cmod"
+#line 401 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
 struct sha1_ctx sha1;
 #endif /* var_sha1_SHA1_State_defined */
 };
@@ -810,7 +812,7 @@ struct sha1_ctx sha1;
 #undef SHA1_State_event_handler_defined
 #define SHA1_State_event_handler_defined
 static void init_SHA1_State_struct(void)
-#line 404 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/hash.cmod"
+#line 404 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
 {
       struct HashState_struct *instance
 	= (struct HashState_struct *) get_storage(Pike_fp->current_object,
@@ -846,8 +848,8 @@ static void SHA1_State_event_handler(int ev) {
 
 #undef class_SHA256_Info_defined
 #define class_SHA256_Info_defined
-struct program *SHA256_Info_program=0;
-int SHA256_Info_program_fun_num=-1;
+struct program *SHA256_Info_program=NULL;
+static int SHA256_Info_program_fun_num=-1;
 
 #undef internal_init_SHA256_Info_defined
 #define internal_init_SHA256_Info_defined
@@ -855,7 +857,7 @@ int SHA256_Info_program_fun_num=-1;
 #undef SHA256_Info_event_handler_defined
 #define SHA256_Info_event_handler_defined
 static void init_SHA256_Info_struct(void)
-#line 426 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/hash.cmod"
+#line 426 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
 {
       struct HashInfo_struct *HashInfo
 	= (struct HashInfo_struct *) get_storage(Pike_fp->current_object,
@@ -895,8 +897,8 @@ static void SHA256_Info_event_handler(int ev) {
 
 #undef class_SHA256_State_defined
 #define class_SHA256_State_defined
-struct program *SHA256_State_program=0;
-int SHA256_State_program_fun_num=-1;
+struct program *SHA256_State_program=NULL;
+static int SHA256_State_program_fun_num=-1;
 
 #undef inherit_SHA256_Info_SHA256_State_defined
 #define inherit_SHA256_Info_SHA256_State_defined
@@ -922,7 +924,7 @@ static ptrdiff_t SHA256_State_storage_offset;
 struct SHA256_State_struct {
 
 #ifdef var_sha256_SHA256_State_defined
-#line 454 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/hash.cmod"
+#line 454 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
 struct sha256_ctx sha256;
 #endif /* var_sha256_SHA256_State_defined */
 };
@@ -933,7 +935,7 @@ struct sha256_ctx sha256;
 #undef SHA256_State_event_handler_defined
 #define SHA256_State_event_handler_defined
 static void init_SHA256_State_struct(void)
-#line 457 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/hash.cmod"
+#line 457 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
 {
       struct HashState_struct *instance
 	= (struct HashState_struct *) get_storage(Pike_fp->current_object,
@@ -963,7 +965,7 @@ static void SHA256_State_event_handler(int ev) {
 
 /*! @endmodule Nettle */
 
-#line 473 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/hash.cmod"
+#line 473 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
 void
 hash_init(void)
 {
@@ -972,8 +974,10 @@ hash_init(void)
 #ifdef class_HashInfo_defined
 
 #ifdef PROG_HASHINFO_ID
+#line 52 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   START_NEW_PROGRAM_ID(HASHINFO);
 #else
+#line 52 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   start_new_program();
 
 #endif /* PROG_HASHINFO_ID */
@@ -997,26 +1001,28 @@ hash_init(void)
 #endif /* HashInfo_event_handler_defined */
 
 #ifdef f_HashInfo_name_defined
-#line 60 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/hash.cmod"
   f_HashInfo_name_fun_num =
+#line 60 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
     ADD_FUNCTION2("name", f_HashInfo_name, tFunc(tNone,tString), 0, OPT_TRY_OPTIMIZE);
 
 #endif /* f_HashInfo_name_defined */
 
 #ifdef f_HashInfo_digest_size_defined
-#line 73 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/hash.cmod"
   f_HashInfo_digest_size_fun_num =
+#line 73 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
     ADD_FUNCTION2("digest_size", f_HashInfo_digest_size, tFunc(tNone,"\10\200\0\0\0\177\377\377\377"), 0, OPT_TRY_OPTIMIZE);
 
 #endif /* f_HashInfo_digest_size_defined */
 
 #ifdef f_HashInfo_block_size_defined
-#line 86 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/hash.cmod"
   f_HashInfo_block_size_fun_num =
+#line 86 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
     ADD_FUNCTION2("block_size", f_HashInfo_block_size, tFunc(tNone,"\10\200\0\0\0\177\377\377\377"), 0, OPT_TRY_OPTIMIZE);
 
 #endif /* f_HashInfo_block_size_defined */
+#line 52 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   HashInfo_program=end_program();
+#line 52 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   HashInfo_program_fun_num=add_program_constant("HashInfo",HashInfo_program,0);
 
 #endif /* class_HashInfo_defined */
@@ -1024,8 +1030,10 @@ hash_init(void)
 #ifdef class_HashState_defined
 
 #ifdef PROG_HASHSTATE_ID
+#line 113 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   START_NEW_PROGRAM_ID(HASHSTATE);
 #else
+#line 113 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   start_new_program();
 
 #endif /* PROG_HASHSTATE_ID */
@@ -1044,6 +1052,7 @@ hash_init(void)
 #endif /* THIS_HASHSTATE */
 
 #ifdef inherit_HashInfo_HashState_defined
+#line 115 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   low_inherit(HashInfo_program, NULL, -1, 0, 0, NULL);
 #endif /* inherit_HashInfo_HashState_defined */
 
@@ -1053,19 +1062,20 @@ hash_init(void)
 #endif /* HashState_event_handler_defined */
 
 #ifdef f_HashState_update_defined
-#line 125 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/hash.cmod"
   f_HashState_update_fun_num =
     ADD_FUNCTION2("update", f_HashState_update, tFunc(tString,tObj), 0, OPT_SIDE_EFFECT);
 
 #endif /* f_HashState_update_defined */
 
 #ifdef f_HashState_digest_defined
-#line 154 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/hash.cmod"
   f_HashState_digest_fun_num =
+#line 154 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
     ADD_FUNCTION2("digest", f_HashState_digest, tFunc(tOr("\10\200\0\0\0\177\377\377\377",tVoid),tString), 0, OPT_EXTERNAL_DEPEND|OPT_SIDE_EFFECT);
 
 #endif /* f_HashState_digest_defined */
+#line 113 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   HashState_program=end_program();
+#line 113 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   HashState_program_fun_num=add_program_constant("HashState",HashState_program,0);
 
 #endif /* class_HashState_defined */
@@ -1073,8 +1083,10 @@ hash_init(void)
 #ifdef class_MD5_Info_defined
 
 #ifdef PROG_MD5_INFO_ID
+#line 210 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   START_NEW_PROGRAM_ID(MD5_INFO);
 #else
+#line 210 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   start_new_program();
 
 #endif /* PROG_MD5_INFO_ID */
@@ -1096,7 +1108,9 @@ hash_init(void)
   pike_set_prog_event_callback(MD5_Info_event_handler);
 
 #endif /* MD5_Info_event_handler_defined */
+#line 210 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   MD5_Info_program=end_program();
+#line 210 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   MD5_Info_program_fun_num=add_program_constant("MD5_Info",MD5_Info_program,0);
 
 #endif /* class_MD5_Info_defined */
@@ -1104,8 +1118,10 @@ hash_init(void)
 #ifdef class_MD5_State_defined
 
 #ifdef PROG_MD5_STATE_ID
+#line 236 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   START_NEW_PROGRAM_ID(MD5_STATE);
 #else
+#line 236 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   start_new_program();
 
 #endif /* PROG_MD5_STATE_ID */
@@ -1124,10 +1140,12 @@ hash_init(void)
 #endif /* THIS_MD5_STATE */
 
 #ifdef inherit_MD5_Info_MD5_State_defined
+#line 238 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   low_inherit(MD5_Info_program, NULL, -1, 0, 0, NULL);
 #endif /* inherit_MD5_Info_MD5_State_defined */
 
 #ifdef inherit_HashState_MD5_State_defined
+#line 239 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   low_inherit(HashState_program, NULL, -1, 0, 0, NULL);
 #endif /* inherit_HashState_MD5_State_defined */
 
@@ -1135,7 +1153,9 @@ hash_init(void)
   pike_set_prog_event_callback(MD5_State_event_handler);
 
 #endif /* MD5_State_event_handler_defined */
+#line 236 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   MD5_State_program=end_program();
+#line 236 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   MD5_State_program_fun_num=add_program_constant("MD5_State",MD5_State_program,0);
 
 #endif /* class_MD5_State_defined */
@@ -1143,8 +1163,10 @@ hash_init(void)
 #ifdef class_MD4_Info_defined
 
 #ifdef PROG_MD4_INFO_ID
+#line 264 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   START_NEW_PROGRAM_ID(MD4_INFO);
 #else
+#line 264 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   start_new_program();
 
 #endif /* PROG_MD4_INFO_ID */
@@ -1166,7 +1188,9 @@ hash_init(void)
   pike_set_prog_event_callback(MD4_Info_event_handler);
 
 #endif /* MD4_Info_event_handler_defined */
+#line 264 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   MD4_Info_program=end_program();
+#line 264 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   MD4_Info_program_fun_num=add_program_constant("MD4_Info",MD4_Info_program,0);
 
 #endif /* class_MD4_Info_defined */
@@ -1174,8 +1198,10 @@ hash_init(void)
 #ifdef class_MD4_State_defined
 
 #ifdef PROG_MD4_STATE_ID
+#line 290 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   START_NEW_PROGRAM_ID(MD4_STATE);
 #else
+#line 290 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   start_new_program();
 
 #endif /* PROG_MD4_STATE_ID */
@@ -1194,10 +1220,12 @@ hash_init(void)
 #endif /* THIS_MD4_STATE */
 
 #ifdef inherit_MD4_Info_MD4_State_defined
+#line 292 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   low_inherit(MD4_Info_program, NULL, -1, 0, 0, NULL);
 #endif /* inherit_MD4_Info_MD4_State_defined */
 
 #ifdef inherit_HashState_MD4_State_defined
+#line 293 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   low_inherit(HashState_program, NULL, -1, 0, 0, NULL);
 #endif /* inherit_HashState_MD4_State_defined */
 
@@ -1205,7 +1233,9 @@ hash_init(void)
   pike_set_prog_event_callback(MD4_State_event_handler);
 
 #endif /* MD4_State_event_handler_defined */
+#line 290 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   MD4_State_program=end_program();
+#line 290 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   MD4_State_program_fun_num=add_program_constant("MD4_State",MD4_State_program,0);
 
 #endif /* class_MD4_State_defined */
@@ -1213,8 +1243,10 @@ hash_init(void)
 #ifdef class_MD2_Info_defined
 
 #ifdef PROG_MD2_INFO_ID
+#line 316 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   START_NEW_PROGRAM_ID(MD2_INFO);
 #else
+#line 316 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   start_new_program();
 
 #endif /* PROG_MD2_INFO_ID */
@@ -1236,7 +1268,9 @@ hash_init(void)
   pike_set_prog_event_callback(MD2_Info_event_handler);
 
 #endif /* MD2_Info_event_handler_defined */
+#line 316 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   MD2_Info_program=end_program();
+#line 316 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   MD2_Info_program_fun_num=add_program_constant("MD2_Info",MD2_Info_program,0);
 
 #endif /* class_MD2_Info_defined */
@@ -1244,8 +1278,10 @@ hash_init(void)
 #ifdef class_MD2_State_defined
 
 #ifdef PROG_MD2_STATE_ID
+#line 342 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   START_NEW_PROGRAM_ID(MD2_STATE);
 #else
+#line 342 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   start_new_program();
 
 #endif /* PROG_MD2_STATE_ID */
@@ -1264,10 +1300,12 @@ hash_init(void)
 #endif /* THIS_MD2_STATE */
 
 #ifdef inherit_MD2_Info_MD2_State_defined
+#line 344 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   low_inherit(MD2_Info_program, NULL, -1, 0, 0, NULL);
 #endif /* inherit_MD2_Info_MD2_State_defined */
 
 #ifdef inherit_HashState_MD2_State_defined
+#line 345 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   low_inherit(HashState_program, NULL, -1, 0, 0, NULL);
 #endif /* inherit_HashState_MD2_State_defined */
 
@@ -1275,7 +1313,9 @@ hash_init(void)
   pike_set_prog_event_callback(MD2_State_event_handler);
 
 #endif /* MD2_State_event_handler_defined */
+#line 342 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   MD2_State_program=end_program();
+#line 342 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   MD2_State_program_fun_num=add_program_constant("MD2_State",MD2_State_program,0);
 
 #endif /* class_MD2_State_defined */
@@ -1283,8 +1323,10 @@ hash_init(void)
 #ifdef class_SHA1_Info_defined
 
 #ifdef PROG_SHA1_INFO_ID
+#line 370 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   START_NEW_PROGRAM_ID(SHA1_INFO);
 #else
+#line 370 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   start_new_program();
 
 #endif /* PROG_SHA1_INFO_ID */
@@ -1306,7 +1348,9 @@ hash_init(void)
   pike_set_prog_event_callback(SHA1_Info_event_handler);
 
 #endif /* SHA1_Info_event_handler_defined */
+#line 370 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   SHA1_Info_program=end_program();
+#line 370 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   SHA1_Info_program_fun_num=add_program_constant("SHA1_Info",SHA1_Info_program,0);
 
 #endif /* class_SHA1_Info_defined */
@@ -1314,8 +1358,10 @@ hash_init(void)
 #ifdef class_SHA1_State_defined
 
 #ifdef PROG_SHA1_STATE_ID
+#line 397 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   START_NEW_PROGRAM_ID(SHA1_STATE);
 #else
+#line 397 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   start_new_program();
 
 #endif /* PROG_SHA1_STATE_ID */
@@ -1334,10 +1380,12 @@ hash_init(void)
 #endif /* THIS_SHA1_STATE */
 
 #ifdef inherit_SHA1_Info_SHA1_State_defined
+#line 399 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   low_inherit(SHA1_Info_program, NULL, -1, 0, 0, NULL);
 #endif /* inherit_SHA1_Info_SHA1_State_defined */
 
 #ifdef inherit_HashState_SHA1_State_defined
+#line 400 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   low_inherit(HashState_program, NULL, -1, 0, 0, NULL);
 #endif /* inherit_HashState_SHA1_State_defined */
 
@@ -1345,7 +1393,9 @@ hash_init(void)
   pike_set_prog_event_callback(SHA1_State_event_handler);
 
 #endif /* SHA1_State_event_handler_defined */
+#line 397 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   SHA1_State_program=end_program();
+#line 397 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   SHA1_State_program_fun_num=add_program_constant("SHA1_State",SHA1_State_program,0);
 
 #endif /* class_SHA1_State_defined */
@@ -1353,8 +1403,10 @@ hash_init(void)
 #ifdef class_SHA256_Info_defined
 
 #ifdef PROG_SHA256_INFO_ID
+#line 423 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   START_NEW_PROGRAM_ID(SHA256_INFO);
 #else
+#line 423 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   start_new_program();
 
 #endif /* PROG_SHA256_INFO_ID */
@@ -1376,7 +1428,9 @@ hash_init(void)
   pike_set_prog_event_callback(SHA256_Info_event_handler);
 
 #endif /* SHA256_Info_event_handler_defined */
+#line 423 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   SHA256_Info_program=end_program();
+#line 423 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   SHA256_Info_program_fun_num=add_program_constant("SHA256_Info",SHA256_Info_program,0);
 
 #endif /* class_SHA256_Info_defined */
@@ -1384,8 +1438,10 @@ hash_init(void)
 #ifdef class_SHA256_State_defined
 
 #ifdef PROG_SHA256_STATE_ID
+#line 450 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   START_NEW_PROGRAM_ID(SHA256_STATE);
 #else
+#line 450 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   start_new_program();
 
 #endif /* PROG_SHA256_STATE_ID */
@@ -1404,10 +1460,12 @@ hash_init(void)
 #endif /* THIS_SHA256_STATE */
 
 #ifdef inherit_SHA256_Info_SHA256_State_defined
+#line 452 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   low_inherit(SHA256_Info_program, NULL, -1, 0, 0, NULL);
 #endif /* inherit_SHA256_Info_SHA256_State_defined */
 
 #ifdef inherit_HashState_SHA256_State_defined
+#line 453 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   low_inherit(HashState_program, NULL, -1, 0, 0, NULL);
 #endif /* inherit_HashState_SHA256_State_defined */
 
@@ -1415,11 +1473,13 @@ hash_init(void)
   pike_set_prog_event_callback(SHA256_State_event_handler);
 
 #endif /* SHA256_State_event_handler_defined */
+#line 450 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   SHA256_State_program=end_program();
+#line 450 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
   SHA256_State_program_fun_num=add_program_constant("SHA256_State",SHA256_State_program,0);
 
 #endif /* class_SHA256_State_defined */
-#line 477 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/hash.cmod"
+#line 477 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
 ;
 }
 
@@ -1430,6 +1490,7 @@ hash_exit(void)
   
 #ifdef class_HashInfo_defined
   if(HashInfo_program) {
+#line 52 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
     free_program(HashInfo_program);
     HashInfo_program=0;
   }
@@ -1438,6 +1499,7 @@ hash_exit(void)
 
 #ifdef class_HashState_defined
   if(HashState_program) {
+#line 113 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
     free_program(HashState_program);
     HashState_program=0;
   }
@@ -1446,6 +1508,7 @@ hash_exit(void)
 
 #ifdef class_MD5_Info_defined
   if(MD5_Info_program) {
+#line 210 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
     free_program(MD5_Info_program);
     MD5_Info_program=0;
   }
@@ -1454,6 +1517,7 @@ hash_exit(void)
 
 #ifdef class_MD5_State_defined
   if(MD5_State_program) {
+#line 236 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
     free_program(MD5_State_program);
     MD5_State_program=0;
   }
@@ -1462,6 +1526,7 @@ hash_exit(void)
 
 #ifdef class_MD4_Info_defined
   if(MD4_Info_program) {
+#line 264 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
     free_program(MD4_Info_program);
     MD4_Info_program=0;
   }
@@ -1470,6 +1535,7 @@ hash_exit(void)
 
 #ifdef class_MD4_State_defined
   if(MD4_State_program) {
+#line 290 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
     free_program(MD4_State_program);
     MD4_State_program=0;
   }
@@ -1478,6 +1544,7 @@ hash_exit(void)
 
 #ifdef class_MD2_Info_defined
   if(MD2_Info_program) {
+#line 316 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
     free_program(MD2_Info_program);
     MD2_Info_program=0;
   }
@@ -1486,6 +1553,7 @@ hash_exit(void)
 
 #ifdef class_MD2_State_defined
   if(MD2_State_program) {
+#line 342 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
     free_program(MD2_State_program);
     MD2_State_program=0;
   }
@@ -1494,6 +1562,7 @@ hash_exit(void)
 
 #ifdef class_SHA1_Info_defined
   if(SHA1_Info_program) {
+#line 370 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
     free_program(SHA1_Info_program);
     SHA1_Info_program=0;
   }
@@ -1502,6 +1571,7 @@ hash_exit(void)
 
 #ifdef class_SHA1_State_defined
   if(SHA1_State_program) {
+#line 397 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
     free_program(SHA1_State_program);
     SHA1_State_program=0;
   }
@@ -1510,6 +1580,7 @@ hash_exit(void)
 
 #ifdef class_SHA256_Info_defined
   if(SHA256_Info_program) {
+#line 423 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
     free_program(SHA256_Info_program);
     SHA256_Info_program=0;
   }
@@ -1518,12 +1589,13 @@ hash_exit(void)
 
 #ifdef class_SHA256_State_defined
   if(SHA256_State_program) {
+#line 450 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
     free_program(SHA256_State_program);
     SHA256_State_program=0;
   }
 
 #endif /* class_SHA256_State_defined */
-#line 484 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/hash.cmod"
+#line 484 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/hash.cmod"
 ;
 }
 
