@@ -1,6 +1,6 @@
-#line 1 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/nt.cmod"
+#line 1 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/nt.cmod"
 /* -*- c -*-
- * $Id: nt.cmod,v 1.9 2004/03/19 14:06:55 grubba Exp $
+ * $Id: nt.cmod,v 1.10 2005/11/04 20:23:55 nilsson Exp $
  */
 
 #ifdef __NT__
@@ -48,8 +48,8 @@
 
 #undef class_CryptContext_defined
 #define class_CryptContext_defined
-struct program *CryptContext_program=0;
-int CryptContext_program_fun_num=-1;
+struct program *CryptContext_program=NULL;
+static int CryptContext_program_fun_num=-1;
 
 #undef var_handle_CryptContext_defined
 #define var_handle_CryptContext_defined
@@ -69,7 +69,7 @@ static ptrdiff_t CryptContext_storage_offset;
 struct CryptContext_struct {
 
 #ifdef var_handle_CryptContext_defined
-#line 51 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/nt.cmod"
+#line 51 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/nt.cmod"
 HCRYPTPROV handle;
 #endif /* var_handle_CryptContext_defined */
 };
@@ -86,24 +86,24 @@ HCRYPTPROV handle;
   #define f_CryptContext_create_defined
 ptrdiff_t f_CryptContext_create_fun_num = 0;
 void f_CryptContext_create(INT32 args) {
-#line 63 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/nt.cmod"
+#line 63 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/nt.cmod"
 struct svalue * str1;
-#line 63 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/nt.cmod"
+#line 63 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/nt.cmod"
 struct svalue * str2;
-#line 63 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/nt.cmod"
+#line 63 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/nt.cmod"
 INT_TYPE type;
-#line 63 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/nt.cmod"
+#line 63 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/nt.cmod"
 INT_TYPE flags;
-#line 63 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/nt.cmod"
+#line 63 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/nt.cmod"
 if(args != 4) wrong_number_of_args_error("create",args,4);
-#line 63 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/nt.cmod"
+#line 63 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/nt.cmod"
 str1=Pike_sp+0-4; dmalloc_touch_svalue(Pike_sp+0-4);
-#line 63 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/nt.cmod"
+#line 63 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/nt.cmod"
 str2=Pike_sp+1-4; dmalloc_touch_svalue(Pike_sp+1-4);
-#line 63 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/nt.cmod"
+#line 63 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/nt.cmod"
 if(Pike_sp[2-4].type != PIKE_T_INT) SIMPLE_BAD_ARG_ERROR("create",3,"int");
 type=Pike_sp[2-4].u.integer;
-#line 63 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/nt.cmod"
+#line 63 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/nt.cmod"
 if(Pike_sp[3-4].type != PIKE_T_INT) SIMPLE_BAD_ARG_ERROR("create",4,"int");
 flags=Pike_sp[3-4].u.integer;
 {
@@ -141,35 +141,37 @@ flags=Pike_sp[3-4].u.integer;
   #define f_CryptContext_read_defined
 ptrdiff_t f_CryptContext_read_fun_num = 0;
 void f_CryptContext_read(INT32 args) {
-#line 96 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/nt.cmod"
+#line 96 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/nt.cmod"
 INT_TYPE size;
-#line 96 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/nt.cmod"
-struct svalue * init;
-#line 96 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/nt.cmod"
+#line 96 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/nt.cmod"
+struct pike_string * init;
+#line 96 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/nt.cmod"
 if(args < 1) wrong_number_of_args_error("read",args,1);
-#line 96 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/nt.cmod"
+#line 96 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/nt.cmod"
 if(args > 2) wrong_number_of_args_error("read",args,2);
-#line 96 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/nt.cmod"
+#line 96 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/nt.cmod"
 if(Pike_sp[0-args].type != PIKE_T_INT) SIMPLE_BAD_ARG_ERROR("read",1,"int");
 size=Pike_sp[0-args].u.integer;
-if (args > 1) {
-#line 96 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/nt.cmod"
-init=Pike_sp+1-args; dmalloc_touch_svalue(Pike_sp+1-args);
+if ((args > 1) && 
+    ((Pike_sp[1-args].type != PIKE_T_INT) ||
+     (Pike_sp[1-args].u.integer))) {
+#line 96 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/nt.cmod"
+if(Pike_sp[1-args].type != PIKE_T_STRING) SIMPLE_BAD_ARG_ERROR("read",2,"string|void");
+#line 96 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/nt.cmod"
+debug_malloc_pass(init=Pike_sp[1-args].u.string);
 } else init=0;
 {
     struct pike_string *res;
-    struct pike_string *str = 0;
     if(size<0)
       Pike_error("Negative string length.\n");
-    if(init && init->type==T_STRING) {
-      str = init->u.string;
-      NO_WIDE_STRING(str);
+    if(init) {
+      NO_WIDE_STRING(init);
       if(size==0)
-	size = str->len;
+	size = init->len;
     }
     res = begin_shared_string(size);
-    if(str && size>0)
-      MEMCPY(res->str, str->str, MINIMUM(str->len,size));
+    if(init && size>0)
+      MEMCPY(res->str, init->str, MINIMUM(init->len,size));
     if(CryptGenRandom(THIS->handle, size, (BYTE*)res->str)) {
       pop_n_elems(args);
       push_string(end_shared_string(res));
@@ -189,7 +191,7 @@ init=Pike_sp+1-args; dmalloc_touch_svalue(Pike_sp+1-args);
 #undef CryptContext_event_handler_defined
 #define CryptContext_event_handler_defined
 static void init_CryptContext_struct(void)
-#line 124 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/nt.cmod"
+#line 122 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/nt.cmod"
 {
     THIS->handle = 0;
   }
@@ -200,7 +202,7 @@ static void init_CryptContext_struct(void)
 #undef CryptContext_event_handler_defined
 #define CryptContext_event_handler_defined
 static void exit_CryptContext_struct(void)
-#line 128 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/nt.cmod"
+#line 126 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/nt.cmod"
 {
     if(THIS->handle)
       CryptReleaseContext(THIS->handle, 0);
@@ -233,15 +235,17 @@ static void CryptContext_event_handler(int ev) {
 /*! @endmodule
  */
 
-#line 143 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/nt.cmod"
+#line 141 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/nt.cmod"
 void nt_init()
 {
   
 #ifdef class_CryptContext_defined
 
 #ifdef PROG_CRYPTCONTEXT_ID
+#line 49 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/nt.cmod"
   START_NEW_PROGRAM_ID(CRYPTCONTEXT);
 #else
+#line 49 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/nt.cmod"
   start_new_program();
 
 #endif /* PROG_CRYPTCONTEXT_ID */
@@ -265,23 +269,25 @@ void nt_init()
 #endif /* CryptContext_event_handler_defined */
 
 #ifdef f_CryptContext_create_defined
-#line 63 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/nt.cmod"
   f_CryptContext_create_fun_num =
+#line 63 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/nt.cmod"
     ADD_FUNCTION2("create", f_CryptContext_create, tFunc(tOr("\10\200\0\0\0\177\377\377\377",tString) tOr("\10\200\0\0\0\177\377\377\377",tString) "\10\200\0\0\0\177\377\377\377" "\10\200\0\0\0\177\377\377\377",tVoid), ID_STATIC, OPT_EXTERNAL_DEPEND|OPT_SIDE_EFFECT);
 
 #endif /* f_CryptContext_create_defined */
 
 #ifdef f_CryptContext_read_defined
-#line 96 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/nt.cmod"
   f_CryptContext_read_fun_num =
+#line 96 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/nt.cmod"
     ADD_FUNCTION2("read", f_CryptContext_read, tFunc("\10\200\0\0\0\177\377\377\377" tOr(tString,tVoid),tString), 0, OPT_EXTERNAL_DEPEND);
 
 #endif /* f_CryptContext_read_defined */
+#line 49 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/nt.cmod"
   CryptContext_program=end_program();
+#line 49 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/nt.cmod"
   CryptContext_program_fun_num=add_program_constant("CryptContext",CryptContext_program,0);
 
 #endif /* class_CryptContext_defined */
-#line 145 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/nt.cmod"
+#line 143 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/nt.cmod"
 ;
 
 #define SIMPCONST(X) \
@@ -311,12 +317,13 @@ void nt_exit()
   
 #ifdef class_CryptContext_defined
   if(CryptContext_program) {
+#line 49 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/nt.cmod"
     free_program(CryptContext_program);
     CryptContext_program=0;
   }
 
 #endif /* class_CryptContext_defined */
-#line 171 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/Nettle/nt.cmod"
+#line 169 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/Nettle/nt.cmod"
 ;
 }
 
