@@ -1,4 +1,4 @@
-#line 1 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/_ADT/adt.cmod"
+#line 1 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/_ADT/adt.cmod"
 /* -*- c -*-
 || This file is part of Pike. For copyright information see COPYRIGHT.
 || Pike is distributed under GPL, LGPL and MPL. See the file COPYING
@@ -11,7 +11,7 @@
 #include "sequence.h"
 #include "circular_list.h"
 
-#line 15 "/export/spare/pike/home/nilsson/Pike/7.6/src/post_modules/_ADT/adt.cmod"
+#line 15 "/home/peter/hack/Pike/7.6-distmaker/src/post_modules/_ADT/adt.cmod"
 PIKE_MODULE_INIT
 {
   ;
