@@ -2,7 +2,7 @@
 || This file is part of Pike. For copyright information see COPYRIGHT.
 || Pike is distributed under GPL, LGPL and MPL. See the file COPYING
 || for more information.
-|| $Id: preprocessor.h,v 1.68 2004/09/18 21:38:57 marcus Exp $
+|| $Id: preprocessor.h,v 1.71 2004/11/02 00:46:44 mast Exp $
 */
 
 /*
@@ -416,8 +416,8 @@ static ptrdiff_t calcC(struct cpp *this, WCHAR *data, ptrdiff_t len,
 
   case '\'':
   {
-    int tmp;
-    READCHAR(tmp);
+    int tmp = data[++pos];
+    if (tmp == '\\') READCHAR(tmp);
     pos++;
     if(!GOBBLE('\''))
       cpp_error(this, "Missing end quote in character constant.");
@@ -1003,6 +1003,19 @@ static ptrdiff_t lower_cpp(struct cpp *this,
       PUTC(' ');
       break;
 
+    case '\\':
+      if(data[pos]=='\n')
+	pos++;
+      else if ((data[pos] == '\r') && (data[pos+1] == '\n'))
+	pos += 2;
+      else {
+	PUTC ('\\');
+	break;
+      }
+      this->current_line++;
+      PUTNL();
+      goto do_skipwhite;
+
     case '\t':
     case ' ':
     case '\r':
@@ -1411,12 +1424,11 @@ static ptrdiff_t lower_cpp(struct cpp *this,
     case '0': case '1': case '2': case '3': case '4':
     case '5': case '6': case '7': case '8': case '9':
     {
-      INT32 tmp;
+      INT32 new_lineno;
       PCHARP foo = MKPCHARP(data+pos, SHIFT);
-      tmp=STRTOL_PCHARP(foo, &foo, 10)-1;
+      new_lineno=STRTOL_PCHARP(foo, &foo, 10)-1;
       if(OUTP())
       {
-	this->current_line=tmp;
 	string_builder_putchar(&this->buf, '#');
 	string_builder_append(&this->buf, MKPCHARP(data+pos, SHIFT),
 			      ((WCHAR *)foo.ptr) - (data+pos));
@@ -1459,7 +1471,10 @@ static ptrdiff_t lower_cpp(struct cpp *this,
 	  free_string_builder(&nf);
 	}
       }
-      
+
+      if (OUTP())
+	this->current_line = new_lineno;
+
       FIND_EOL();
       break;
     }
