@@ -2,13 +2,17 @@
 || This file is part of Pike. For copyright information see COPYRIGHT.
 || Pike is distributed under GPL, LGPL and MPL. See the file COPYING
 || for more information.
-|| $Id: program_areas.h,v 1.13 2003/04/02 19:22:44 mast Exp $
+|| $Id: program_areas.h,v 1.14 2005/05/26 12:00:45 grubba Exp $
 */
 
 /* Who needs templates anyway? / Hubbe */
 
+#ifndef BAR
+#define BAR(NUMTYPE, TYPE, ARGTYPE, NAME) FOO(NUMTYPE, TYPE, ARGTYPE, NAME)
+#endif /* !BAR */
+
 /* Program *must* be first! */
-FOO(size_t,PIKE_OPCODE_T, PIKE_OPCODE_T, program)
+BAR(size_t,PIKE_OPCODE_T, PIKE_OPCODE_T, program)
 FOO(size_t,size_t, size_t, relocations)
 FOO(size_t,char, int, linenumbers)
 FOO(unsigned INT16,unsigned INT16, unsigned, identifier_index)
@@ -19,3 +23,4 @@ FOO(unsigned INT16,struct inherit, struct inherit, inherits)
 FOO(unsigned INT16,struct identifier, struct identifier, identifiers)
 FOO(unsigned INT16,struct program_constant, struct program_constant, constants)
 #undef FOO
+#undef BAR
