@@ -2,7 +2,7 @@
 || This file is part of Pike. For copyright information see COPYRIGHT.
 || Pike is distributed under GPL, LGPL and MPL. See the file COPYING
 || for more information.
-|| $Id: stralloc.c,v 1.165 2004/04/15 17:34:40 mast Exp $
+|| $Id: stralloc.c,v 1.171 2006/03/14 17:39:03 grubba Exp $
 */
 
 #include "global.h"
@@ -24,7 +24,7 @@
 #include <ctype.h>
 #include <math.h>
 
-RCSID("$Id: stralloc.c,v 1.165 2004/04/15 17:34:40 mast Exp $");
+RCSID("$Id: stralloc.c,v 1.171 2006/03/14 17:39:03 grubba Exp $");
 
 /* #define STRALLOC_USE_PRIMES */
 
@@ -461,12 +461,26 @@ static struct pike_string *propagate_shared_string(const struct pike_string *s,
 
 static void rehash_string_backwards(struct pike_string *s)
 {
-  ptrdiff_t h;
+  struct pike_string *prev = NULL;
+  struct pike_string *next;
+
   if(!s) return;
-  rehash_string_backwards(s->next);
-  h = HMODULO(s->hval);
-  s->next=base_table[h];
-  base_table[h]=s;
+
+  /* Reverse the hash list. */
+  while ((next = s->next)) {
+    s->next = prev;
+    prev = s;
+    s = next;
+  }
+  s->next = prev;
+
+  /* Rehash the strings for this list. */
+  do {
+    ptrdiff_t h = HMODULO(s->hval);
+    next = s->next;
+    s->next = base_table[h];
+    base_table[h] = s;
+  } while ((s = next));
 }
 
 static void stralloc_rehash(void)
@@ -1292,9 +1306,12 @@ PMOD_EXPORT ptrdiff_t generic_quick_binary_strcmp(const char *a,
     INT32 pos;
     for(pos=0;pos< MINIMUM(alen,blen) ;pos++)
     {
-      INT32 ac=generic_extract(a,asize,pos);
-      INT32 bc=generic_extract(b,bsize,pos);
-      if(ac-bc) return ac-bc;
+      p_wchar2 ac=generic_extract(a,asize,pos);
+      p_wchar2 bc=generic_extract(b,bsize,pos);
+      if(ac != bc) {
+	if (ac < bc) return -1;
+	return 1;
+      }
     }
     return alen-blen;
   }
@@ -1571,8 +1588,19 @@ PMOD_EXPORT struct pike_string *modify_shared_string(struct pike_string *a,
 
     if((((unsigned int)index) >= HASH_PREFIX) && (index < a->len-8))
     {
+      struct pike_string *old;
       /* Doesn't change hash value - sneak it in there */
       low_set_index(a,index,c);
+      unlink_pike_string(a);
+      old = internal_findstring(a->str, a->len, a->size_shift, a->hval);
+      if (old) {
+	/* The new string is equal to some old string. */
+	really_free_pike_string(a);
+	add_ref(a = old);
+      } else {
+	link_pike_string(a, a->hval);
+	add_ref(a);
+      }
       return a;
     }else{
       unlink_pike_string(a);
@@ -1820,7 +1848,7 @@ void init_shared_string_table(void)
   empty_pike_string = make_shared_string("");
 }
 
-#ifdef DEBUG_MALLOC
+#ifdef DO_PIKE_CLEANUP
 struct shared_string_location *all_shared_string_locations;
 #endif
 
@@ -1835,7 +1863,7 @@ void cleanup_shared_string_table(void)
     empty_pike_string = 0;
   }
 
-#if defined(PIKE_DEBUG) && defined(DEBUG_MALLOC)
+#ifdef DO_PIKE_CLEANUP
   while(all_shared_string_locations)
   {
     struct shared_string_location *x=all_shared_string_locations;
@@ -1844,14 +1872,16 @@ void cleanup_shared_string_table(void)
     x->s=0;
   }
 
-  if(verbose_debug_exit)
+  if (exit_with_cleanup)
   {
     INT32 num,size;
     count_memory_in_strings(&num,&size);
     if(num)
     {
       fprintf(stderr,"Strings left: %d (%d bytes) (zapped)\n",num,size);
+#ifdef PIKE_DEBUG
       dump_stralloc_strings();
+#endif
     }
   }
 #endif
